package com.ruoyi.rocketmq.service;

import java.util.List;
import com.ruoyi.rocketmq.domain.RmAlarmLog;

/**
 * 客户端告警信息Service接口
 * 
 * @author gyt
 * @date 2025-11-10
 */
public interface IRmAlarmLogService 
{
    /**
     * 查询客户端告警信息
     * 
     * @param id 客户端告警信息主键
     * @return 客户端告警信息
     */
    public RmAlarmLog selectRmAlarmLogById(Long id);

    /**
     * 查询客户端告警信息列表
     * 
     * @param rmAlarmLog 客户端告警信息
     * @return 客户端告警信息集合
     */
    public List<RmAlarmLog> selectRmAlarmLogList(RmAlarmLog rmAlarmLog);

    /**
     * 新增客户端告警信息
     * 
     * @param rmAlarmLog 客户端告警信息
     * @return 结果
     */
    public int insertRmAlarmLog(RmAlarmLog rmAlarmLog);

    /**
     * 修改客户端告警信息
     * 
     * @param rmAlarmLog 客户端告警信息
     * @return 结果
     */
    public int updateRmAlarmLog(RmAlarmLog rmAlarmLog);

    /**
     * 批量删除客户端告警信息
     * 
     * @param ids 需要删除的客户端告警信息主键集合
     * @return 结果
     */
    public int deleteRmAlarmLogByIds(Long[] ids);

    /**
     * 删除客户端告警信息信息
     * 
     * @param id 客户端告警信息主键
     * @return 结果
     */
    public int deleteRmAlarmLogById(Long id);
}
